78 chars is good enough to wrap help
authorAlexander Solovyov <piranha@piranha.org.ua>
Thu, 02 Jul 2009 21:36:40 +0300
changeset 26 42f2917b59ec
parent 25 2854f81bfc8b
child 27 3908a489c02e
78 chars is good enough to wrap help
fancycmd.py
--- a/fancycmd.py	Sun Jun 28 19:53:20 2009 +0300
+++ b/fancycmd.py	Thu Jul 02 21:36:40 2009 +0300
@@ -170,8 +170,8 @@
     opts_len = max([len(first) for first, second in output if second] or [0])
     for first, second in output:
         if second:
-            # wrap description at 70 chars
-            second = textwrap.wrap(second, width=(70 - opts_len - 3))
+            # wrap description at 78 chars
+            second = textwrap.wrap(second, width=(78 - opts_len - 3))
             pad = '\n' + ' ' * (opts_len + 3)
             yield ' %-*s  %s\n' % (opts_len, first, pad.join(second))
         else: